==> walkers-fabric-1.18.2-5.3.3-sources.jar: tocraft/walkers/mixin/player/PlayerSonicBoomMixin.java <==
//#if MC>1182
package tocraft.walkers.mixin.player;

import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1493;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3419;
import net.minecraft.class_3532;
import net.minecraft.class_5134;
import net.minecraft.world.entity.monster.warden.Warden;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import tocraft.craftedcore.patched.CEntity;
import tocraft.walkers.api.PlayerShape;
import tocraft.walkers.impl.SonicBoomUser;

import java.util.HashSet;
import java.util.Set;

@Mixin(class_1657.class)
public abstract class PlayerSonicBoomMixin extends class_1309 implements SonicBoomUser {

    @Unique
    private int shape$ability_wardenBoomDelay = -1;

    private PlayerSonicBoomMixin(class_1299<? extends class_1309> type, class_1937 world) {
        super(type, world);
    }

    @Override
    public void shape$ability_startSonicBoom() {
        @Nullable class_1309 shape = PlayerShape.getCurrentShape((class_1657) (Object) this);
        if (shape instanceof Warden) {
            CEntity.level(this).method_8421(this, EntityEvent.SONIC_CHARGE);
            shape$ability_wardenBoomDelay = 40;

            // SFX
            CEntity.level(this).method_8465(null, method_23317(), method_23318(), method_23321(), SoundEvents.WARDEN_SONIC_CHARGE, class_3419.field_15248, 3.0f, 1.0f);
        }
    }

    @Inject(method = "tick", at = @At("HEAD"))
    private void tickSonicBoom(CallbackInfo ci) {
        if (!CEntity.level(this).field_9236) {
            shape$ability_wardenBoomDelay = Math.max(-1, shape$ability_wardenBoomDelay - 1);
            if (shape$ability_wardenBoomDelay == 0) {

                // SFX
                CEntity.level(this).method_8465(null, method_23317(), method_23318(), method_23321(), SoundEvents.WARDEN_SONIC_BOOM, class_3419.field_15248, 3.0f, 1.0f);

                // Raycast out for sonic boom effect
                float heightOffset = 1.6f;
                int distance = 16;
                class_243 target = method_19538().method_1019(method_5720().method_1021(distance));
                class_243 source = method_19538().method_1031(0.0, heightOffset, 0.0);
                class_243 offsetToTarget = target.method_1020(source);
                class_243 normalized = offsetToTarget.method_1029();

                // Spawn particles from the source to the target
                Set<class_1297> hit = new HashSet<>();
                for (int particleIndex = 1; particleIndex < class_3532.method_15357(offsetToTarget.method_1033()) + 7; ++particleIndex) {
                    class_243 particlePos = source.method_1019(normalized.method_1021(particleIndex));
                    ((class_3218) CEntity.level(this)).method_14199(ParticleTypes.SONIC_BOOM, particlePos.field_1352, particlePos.field_1351, particlePos.field_1350, 1, 0.0, 0.0, 0.0, 0.0);

                    // Locate entities around the particle location for damage
                    hit.addAll(CEntity.level(this).method_8390(class_1309.class, new class_238(class_2338.containing(particlePos.method_10216(), particlePos.method_10214(), particlePos.method_10215())).method_1014(2), it -> !(it instanceof class_1493)));
                }

                // Don't hit ourselves
                hit.remove((class_1657) (Object) this);

                // Find
                for (class_1297 hitTarget : hit) {
                    if (hitTarget instanceof class_1309 living) {
                        living.method_5643(CEntity.level(this).damageSources().sonicBoom((class_1657) (Object) this), 10.0f);
                        double vertical = 0.5 * (1.0 - living.method_26825(class_5134.field_23718));
                        double horizontal = 2.5 * (1.0 - living.method_26825(class_5134.field_23718));
                        living.method_5762(normalized.method_10216() * horizontal, normalized.method_10214() * vertical, normalized.method_10215() * horizontal);
                    }
                }
            }
        }
    }
}
//#endif

==> walkers-fabric-1.19.4-5.2-sources.jar: tocraft/walkers/mixin/player/PlayerSonicBoomMixin.java <==
//#if MC>1182
package tocraft.walkers.mixin.player;

import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import tocraft.craftedcore.patched.CEntity;
import tocraft.walkers.api.PlayerShape;
import tocraft.walkers.impl.SonicBoomUser;

import java.util.HashSet;
import java.util.Set;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1493;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3532;
import net.minecraft.class_5134;
import net.minecraft.class_6024;
import net.minecraft.class_7260;

@Mixin(class_1657.class)
public abstract class PlayerSonicBoomMixin extends class_1309 implements SonicBoomUser {

    @Unique
    private int shape$ability_wardenBoomDelay = -1;

    private PlayerSonicBoomMixin(class_1299<? extends class_1309> type, class_1937 world) {
        super(type, world);
    }

    @Override
    public void shape$ability_startSonicBoom() {
        @Nullable class_1309 shape = PlayerShape.getCurrentShape((class_1657) (Object) this);
        if (shape instanceof class_7260) {
            CEntity.level(this).method_8421(this, class_6024.field_38847);
            shape$ability_wardenBoomDelay = 40;

            // SFX
            CEntity.level(this).method_43128(null, method_23317(), method_23318(), method_23321(), class_3417.field_38831, class_3419.field_15248, 3.0f, 1.0f);
        }
    }

    @Inject(method = "tick", at = @At("HEAD"))
    private void tickSonicBoom(CallbackInfo ci) {
        if (!CEntity.level(this).field_9236) {
            shape$ability_wardenBoomDelay = Math.max(-1, shape$ability_wardenBoomDelay - 1);
            if (shape$ability_wardenBoomDelay == 0) {

                // SFX
                CEntity.level(this).method_43128(null, method_23317(), method_23318(), method_23321(), class_3417.field_38830, class_3419.field_15248, 3.0f, 1.0f);

                // Raycast out for sonic boom effect
                float heightOffset = 1.6f;
                int distance = 16;
                class_243 target = method_19538().method_1019(method_5720().method_1021(distance));
                class_243 source = method_19538().method_1031(0.0, heightOffset, 0.0);
                class_243 offsetToTarget = target.method_1020(source);
                class_243 normalized = offsetToTarget.method_1029();

                // Spawn particles from the source to the target
                Set<class_1297> hit = new HashSet<>();
                for (int particleIndex = 1; particleIndex < class_3532.method_15357(offsetToTarget.method_1033()) + 7; ++particleIndex) {
                    class_243 particlePos = source.method_1019(normalized.method_1021(particleIndex));
                    ((class_3218) CEntity.level(this)).method_14199(class_2398.field_38908, particlePos.field_1352, particlePos.field_1351, particlePos.field_1350, 1, 0.0, 0.0, 0.0, 0.0);

                    // Locate entities around the particle location for damage
                    hit.addAll(CEntity.level(this).method_8390(class_1309.class, new class_238(class_2338.method_49637(particlePos.method_10216(), particlePos.method_10214(), particlePos.method_10215())).method_1014(2), it -> !(it instanceof class_1493)));
                }

                // Don't hit ourselves
                hit.remove((class_1657) (Object) this);

                // Find
                for (class_1297 hitTarget : hit) {
                    if (hitTarget instanceof class_1309 living) {
                        living.method_5643(CEntity.level(this).method_48963().method_48821((class_1657) (Object) this), 10.0f);
                        double vertical = 0.5 * (1.0 - living.method_26825(class_5134.field_23718));
                        double horizontal = 2.5 * (1.0 - living.method_26825(class_5134.field_23718));
                        living.method_5762(normalized.method_10216() * horizontal, normalized.method_10214() * vertical, normalized.method_10215() * horizontal);
                    }
                }
            }
        }
    }
}
//#endif
